serpstatr: serpstatr: Serpstat API wrapper for R.

serpstatrR Documentation

serpstatr: Serpstat API wrapper for R.

Description

The serpstatr package covers main Serpstat API methods. All the names of the functions start with sst_ to reduce the name conflict with other packages.

Details

All the required arguments are checked by the API endpoint. So you would not get an error in R but the response would contain error object.

Functions naming

The names of the package functions start with sst_sa_

  • sst_sa_database_info

  • sst_sa_stats

Author(s)

Maintainer: Alex Danilin alexnikdanilin@gmail.com

Authors:

See Also

Useful links:


serpstatr documentation built on June 10, 2026, 1:06 a.m.