| sst_au_get_summary | R Documentation |
Returns the basic stats for the finished audit returns, including number of checked pages, issues by priority, domain optimization score.
sst_au_get_summary(
api_token = Sys.getenv("SERPSTAT_API_TOKEN"),
report_id = NULL,
return_method = "list"
)
api_token |
(required) Serpstat API token from your profile. Default is Sys.getenv('SERPSTAT_API_TOKEN'). |
report_id |
(required) ID of the audit report to get data from. |
return_method |
(optional) Accepted values are 'list' (default) to return data object as list or 'df' to return data object as data.frame. |
Returns the basic metrics for audited website.
Check all the values for request and response fields here.
0.
## Not run:
sst_au_get_summary(
report_id = report_id
)$data
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.