| sst_au_start | R Documentation |
Starts a project website audit with the current audit settings. Uses default audit settings if no settings were changed.
sst_au_start(
api_token = Sys.getenv("SERPSTAT_API_TOKEN"),
project_id = NULL,
return_method = "list"
)
api_token |
(required) Serpstat API token from your profile. Default is Sys.getenv('SERPSTAT_API_TOKEN'). |
project_id |
(required) ID of the project in Serpstat. |
return_method |
(optional) Accepted values are 'list' (default) to return data object as list or 'df' to return data object as data.frame. |
Returns the ID of the audit report.
Check all the values for request and response fields here.
1 audit credit for each checked page.
## Not run:
sst_au_start(
project_id = 12345
)$data$reportId
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.