sst_bl_domain_summary: Backlinks summary

View source: R/backlinks.R

sst_bl_domain_summaryR Documentation

Backlinks summary

Description

Returns the overview of the backlinks profile for the domain.

Usage

sst_bl_domain_summary(
  domain,
  search_type = "domain",
  return_method = "list",
  api_token = Sys.getenv("SERPSTAT_API_TOKEN")
)

Arguments

domain

(required) A domain name to analyze.

search_type

(optional) Default value is 'domain' for domain only (site.com). See API docs for more details.

return_method

(optional) Accepted values are 'list' (default) to return data object as list or 'df' to return data object as data.frame.

api_token

(required) Serpstat API token from your profile. Default is Sys.getenv('SERPSTAT_API_TOKEN').

Value

Returns aggregated backlinks data for the domain.

API docs

Check all the values for request and response fields here.

API credits consumption

1 per request.

Examples

## Not run: 
sst_bl_domain_summary(
  domain        = 'serpstat.com',
  search_type   = 'domain',
  return_method = 'list'
)$data

## End(Not run)

serpstatr documentation built on June 10, 2026, 1:06 a.m.