sst_pm_create_project: Create a new project

View source: R/project_management.R

sst_pm_create_projectR Documentation

Create a new project

Description

Creates a new project in Serpstat.

Usage

sst_pm_create_project(
  domain,
  name,
  groups = NULL,
  return_method = "list",
  api_token = Sys.getenv("SERPSTAT_API_TOKEN")
)

Arguments

domain

(required) Domain to get data for.

name

(required) The name of the project. Can be different from the domain.

groups

(optional) A list of project groups the project should be added to.

return_method

(optional) Accepted values are 'list' (default) to return data object as list or 'df' to return data object as data.frame.

api_token

(required) Serpstat API token from your profile. Default is Sys.getenv('SERPSTAT_API_TOKEN').

Value

Returns the project ID for the created project.

API docs

Check all the values for request and response fields here.

API credits consumption

1 project credit.

Examples

## Not run: 
sst_pm_create_project(
  domain    = 'serpstat.com',
  name      = 'Serpstat'
  )$data$project_id

## End(Not run)

serpstatr documentation built on June 10, 2026, 1:06 a.m.