sst_pm_delete_project: Delete the existing project

View source: R/project_management.R

sst_pm_delete_projectR Documentation

Delete the existing project

Description

Deletes the existing project in Serpstat by project ID.

Usage

sst_pm_delete_project(
  api_token = Sys.getenv("SERPSTAT_API_TOKEN"),
  project_id = NULL,
  return_method = "list"
)

Arguments

api_token

(required) Serpstat API token from your profile.Default is Sys.getenv('SERPSTAT_API_TOKEN').

project_id

(required) ID of the project in Serpstat.

return_method

(optional) Accepted values are 'list' (default) to return data object as list or 'df' to return data object as data.frame.

Value

Returns the state of the deletion operation.

API docs

Check all the values for request and response fields here.

API credits consumption

returns 1 project credit.

Examples

## Not run: 
sst_pm_delete_project(
  project_id = 12345
  )

## End(Not run)

serpstatr documentation built on June 10, 2026, 1:06 a.m.