sst_pm_list_projects: List existing projects

View source: R/project_management.R

sst_pm_list_projectsR Documentation

List existing projects

Description

Gets a list of existing projects available for the users with their basic information.

Usage

sst_pm_list_projects(
  page = 1,
  size = 100,
  return_method = "list",
  api_token = Sys.getenv("SERPSTAT_API_TOKEN")
)

Arguments

page

(optional) Response page number if there are many pages in response.

size

(optional) Response page size.

return_method

(optional) Accepted values are 'list' (default) to return data object as list or 'df' to return data object as data.frame.

api_token

(required) Serpstat API token from your profile. Default is Sys.getenv('SERPSTAT_API_TOKEN').

Value

Returns basic information on all the projects.

API docs

Check all the values for request and response fields here.

API credits consumption

0.

Examples

## Not run: 
sst_pm_list_projects(
  page       = 2,
  size       = 10
  )

## End(Not run)

serpstatr documentation built on June 10, 2026, 1:06 a.m.