View source: R/search_analytics.R
| sst_sa_domain_keywords_per_region | R Documentation |
Returns the number of keywords for each region for a domain. Regions with no keywords are not returned.
sst_sa_domain_keywords_per_region(
domain,
sort = "keywords_count",
order = "desc",
return_method = "list",
api_token = Sys.getenv("SERPSTAT_API_TOKEN")
)
domain |
(required) A domain name to analyze. |
sort |
(optional) A field to sort the response. Allowed values: keywords_count, db_name, country_name_en, google_domain. Default: keywords_count. |
order |
(optional) The order of sorting. Allowed values: asc, desc. Default: desc. |
return_method |
(optional) Accepted values are 'list' (default) to return data object as list or 'df' to return data object as data.frame. |
api_token |
(required) Serpstat API token from your profile. Default is Sys.getenv('SERPSTAT_API_TOKEN'). |
Returns a data frame with number of keywords for each region for a domain.
Check all the values for request and response fields here.
1 per returned region.
## Not run:
sst_sa_domain_keywords_per_region(
domain = 'serpstat.com',
sort = 'keywords_count',
order = 'desc',
return_method = 'df'
)$data
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.