View source: R/search_analytics.R
| sst_sa_keyword_trends | R Documentation |
Returns monthly search volume trends for a list of keywords over a specified period (up to 48 months). You can send up to 100 keywords per request.
sst_sa_keyword_trends(
keywords,
se,
months = 48,
return_method = "list",
api_token = Sys.getenv("SERPSTAT_API_TOKEN")
)
keywords |
(required) A vector of keywords to analyze. |
se |
(required) Search engine alias (db_name) returned by
|
months |
(optional) Number of months to get data for (up to 48). Default is 48. |
return_method |
(optional) Accepted values are 'list' (default) to return data object as list or 'df' to return data object as data.frame. |
api_token |
(required) Serpstat API token from your profile. Default is Sys.getenv('SERPSTAT_API_TOKEN'). |
Returns monthly search volume trends for each keyword.
Check all the values for request and response fields here.
10 credits per keyword that returned data. If no keywords returned data — 1 credit is charged for the whole request.
## Not run:
sst_sa_keyword_trends(
keywords = c('seo', 'ppc', 'serpstat'),
se = 'g_us',
months = 12,
return_method = 'df'
)$data
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.