(required) Search engine alias (db_name) returned by
sst_sa_database_info.
sort
(optional) A field to sort the response. See Sorting for more
details.
return_method
(optional) Accepted values are 'list' (default) to
return data object as list or 'df' to return data object as data.frame.
api_token
(required) Serpstat API token from
your profile. Default is Sys.getenv('SERPSTAT_API_TOKEN').
API docs
Check all the values for request and response fields here.
API credits consumption
1 per keyword in request.
Sorting
You can sort the response using sort argument. It must be a list
with a single named element. The name of the element must match one of
parameters in response. The value of the element must be asc for
ascending order and desc for descending order. For example,
sort = list(ads = 'desc') would sort the response by ads
parameter in descending order.