powered by
With most API request you spend some amount of API rows. The total amount of API rows available for you is based on your plan. Use this method to control the amount of API rows left.
sst_sa_stats(api_token = Sys.getenv("SERPSTAT_API_TOKEN"))
Returns a number of API rows left. Also returns some additional information about user and
Serpstat plugin limits.
(required) Serpstat API token from your profile. Default is Sys.getenv('SERPSTAT_API_TOKEN').
0
if (FALSE) { sst_sa_stats()$summary_info$left_lines }
Run the code above in your browser using DataLab