| serpstatr | R Documentation |
The serpstatr package covers main Serpstat API methods.
All the names of the functions start with sst_ to reduce
the name conflict with other packages.
All the required arguments are checked by the API endpoint. So you would not
get an error in R but the response would contain error object.
The names of the package functions start with sst_sa_
sst_sa_database_info
sst_sa_stats
Maintainer: Alex Danilin alexnikdanilin@gmail.com
Authors:
Alex Danilin alexnikdanilin@gmail.com
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.