powered by
Returns the basic stats for the finished audit returns, including number of checked pages, issues by priority, domain optimization score.
sst_au_get_summary( api_token = Sys.getenv("SERPSTAT_API_TOKEN"), report_id = NULL )
Returns the basic metrics for audited website.
(required) Serpstat API token from your profile. Default is Sys.getenv('SERPSTAT_API_TOKEN').
(required) ID of the audit report to get data from.
Check all the values for request and response fields here.
0.
if (FALSE) { sst_au_get_summary( report_id = report_id )$data }
Run the code above in your browser using DataLab