Learn R Programming

serpstatr (version 0.4.0)

sst_au_start: Start a website audit

Description

Starts a project website audit with the current audit settings. Uses default audit settings if no settings were changed.

Usage

sst_au_start(api_token = Sys.getenv("SERPSTAT_API_TOKEN"), project_id = NULL)

Value

Returns the ID of the audit report.

Arguments

api_token

(required) Serpstat API token from your profile. Default is Sys.getenv('SERPSTAT_API_TOKEN').

project_id

(required) ID of the project in Serpstat.

API docs

Check all the values for request and response fields here.

API credits consumption

1 audit credit for each checked page.

Examples

Run this code
if (FALSE) {
sst_au_start(
  project_id = 12345
  )$data$reportId
}

Run the code above in your browser using DataLab