powered by
Starts a project website audit with the current audit settings. Uses default audit settings if no settings were changed.
sst_au_start(api_token = Sys.getenv("SERPSTAT_API_TOKEN"), project_id = NULL)
Returns the ID of the audit report.
(required) Serpstat API token from your profile. Default is Sys.getenv('SERPSTAT_API_TOKEN').
(required) ID of the project in Serpstat.
Check all the values for request and response fields here.
1 audit credit for each checked page.
if (FALSE) { sst_au_start( project_id = 12345 )$data$reportId }
Run the code above in your browser using DataLab