Learn R Programming

serpstatr (version 0.4.0)

sst_bl_domain_summary: Backlinks summary

Description

Returns the overview of the backlinks profile for the domain.

Usage

sst_bl_domain_summary(
  domain,
  search_type = "domain",
  return_method = "list",
  api_token = Sys.getenv("SERPSTAT_API_TOKEN")
)

Value

Returns aggregated backlinks data for the domain.

Arguments

domain

(required) A domain name to analyze.

search_type

(optional) Default value is 'domain' for domain only (site.com). See API docs for more details.

return_method

(optional) Accepted values are 'list' (default) to return data object as list or 'df' to return data object as data.frame.

api_token

(required) Serpstat API token from your profile. Default is Sys.getenv('SERPSTAT_API_TOKEN').

API docs

Check all the values for request and response fields here.

API credits consumption

1 per request.

Examples

Run this code
if (FALSE) {
sst_bl_domain_summary(
  domain        = 'serpstat.com',
  search_type   = 'domain',
  return_method = 'list'
)$data
}

Run the code above in your browser using DataLab