powered by
Returns the overview of the backlinks profile for the domain.
sst_bl_domain_summary( domain, search_type = "domain", return_method = "list", api_token = Sys.getenv("SERPSTAT_API_TOKEN") )
Returns aggregated backlinks data for the domain.
(required) A domain name to analyze.
(optional) Default value is 'domain' for domain only (site.com). See API docs for more details.
(optional) Accepted values are 'list' (default) to return data object as list or 'df' to return data object as data.frame.
(required) Serpstat API token from your profile. Default is Sys.getenv('SERPSTAT_API_TOKEN').
Check all the values for request and response fields here.
1 per request.
if (FALSE) { sst_bl_domain_summary( domain = 'serpstat.com', search_type = 'domain', return_method = 'list' )$data }
Run the code above in your browser using DataLab