View source: R/project_management.R
| sst_pm_delete_project | R Documentation |
Deletes the existing project in Serpstat by project ID.
sst_pm_delete_project(
api_token = Sys.getenv("SERPSTAT_API_TOKEN"),
project_id = NULL,
return_method = "list"
)
api_token |
(required) Serpstat API token from your profile.Default is Sys.getenv('SERPSTAT_API_TOKEN'). |
project_id |
(required) ID of the project in Serpstat. |
return_method |
(optional) Accepted values are 'list' (default) to return data object as list or 'df' to return data object as data.frame. |
Returns the state of the deletion operation.
Check all the values for request and response fields here.
returns 1 project credit.
## Not run:
sst_pm_delete_project(
project_id = 12345
)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.