Learn R Programming

serpstatr (version 0.4.0)

sst_pm_delete_project: Delete the existing project

Description

Deletes the existing project in Serpstat by project ID.

Usage

sst_pm_delete_project(
  api_token = Sys.getenv("SERPSTAT_API_TOKEN"),
  project_id = NULL
)

Value

Returns the state of the deletion operation.

Arguments

api_token

(required) Serpstat API token from your profile.Default is Sys.getenv('SERPSTAT_API_TOKEN').

project_id

(required) ID of the project in Serpstat.

API docs

Check all the values for request and response fields here.

API credits consumption

returns 1 project credit.

Examples

Run this code
if (FALSE) {
sst_pm_delete_project(
  project_id = 12345
  )
}

Run the code above in your browser using DataLab