powered by
Deletes the existing project in Serpstat by project ID.
sst_pm_delete_project( api_token = Sys.getenv("SERPSTAT_API_TOKEN"), project_id = NULL )
Returns the state of the deletion operation.
(required) Serpstat API token from your profile.Default is Sys.getenv('SERPSTAT_API_TOKEN').
(required) ID of the project in Serpstat.
Check all the values for request and response fields here.
returns 1 project credit.
if (FALSE) { sst_pm_delete_project( project_id = 12345 ) }
Run the code above in your browser using DataLab