View source: R/search_analytics.R
| sst_sa_keyword_top | R Documentation |
Returns a list of results (URLs) from search engine results page (SERP) including organic results, paid results and different types of SERP features.
sst_sa_keyword_top(
keyword,
se,
sort = NULL,
size = 100,
api_token = Sys.getenv("SERPSTAT_API_TOKEN")
)
keyword |
(required) A keyword to search for. |
se |
(required) Search engine alias (db_name) returned by
|
sort |
(optional) A field to sort the response. See API docs for more details. |
size |
(optional) Response page size. Should be => 10 and <=100. Default is 100. |
api_token |
(required) Serpstat API token from your profile. Default is Sys.getenv('SERPSTAT_API_TOKEN'). |
Returns a list with the data about search engine results page for the keyword.
Check all the values for request and response fields here.
1 per URL in response.
## Not run:
sst_sa_keyword_top(
keyword = 'serpstat',
se = 'g_us',
size = 10
)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.