Learn R Programming

serpstatr (version 0.4.0)

sst_sa_keyword_top: Top for a keyword

Description

Returns a list of results (URLs) from search engine results page (SERP) including organic results, paid results and different types of SERP features.

Usage

sst_sa_keyword_top(
  keyword,
  se,
  sort = NULL,
  size = 100,
  api_token = Sys.getenv("SERPSTAT_API_TOKEN")
)

Value

Returns a list with the data about search engine results page for the keyword.

Arguments

keyword

(required) A keyword to search for.

se

(required) Search engine alias (db_name) returned by sst_sa_database_info.

sort

(optional) A field to sort the response. See API docs for more details.

size

(optional) Response page size. Should be => 10 and <=100. Default is 100.

api_token

(required) Serpstat API token from your profile. Default is Sys.getenv('SERPSTAT_API_TOKEN').

API docs

Check all the values for request and response fields here.

API credits consumption

1 per URL in response.

Examples

Run this code
if (FALSE) {
sst_sa_keyword_top(
  keyword   = 'serpstat',
  se        = 'g_us',
  size  = 10
)
}

Run the code above in your browser using DataLab