Learn R Programming

serpstatr (version 0.4.0)

sst_sa_related_keywords: Related keywords for a keyword

Description

Returns a list of semantically related keywords for a given keyword.

Usage

sst_sa_related_keywords(
  keyword,
  se,
  with_intents = FALSE,
  filters = NULL,
  sort = NULL,
  page = 1,
  size = 100,
  return_method = "list",
  api_token = Sys.getenv("SERPSTAT_API_TOKEN")
)

Value

Returns related keywords for a keyword and their metrics.

Arguments

keyword

(required) A keyword to search for.

se

(required) Search engine alias (db_name) returned by sst_sa_database_info.

with_intents

(optional) TRUE if keyword intent should be retrieved. This parameter works for g_ua and g_us database only.

filters

(optional) A list of filtering options. See API docs for more details.

sort

(optional) A field to sort the response. See API docs for more details.

page

(optional) Response page number if there are many pages in response.

size

(optional) Response page size.

return_method

(optional) Accepted values are 'list' (default) to return data object as list or 'df' to return data object as data.frame.

api_token

(required) Serpstat API token from your profile. Default is Sys.getenv('SERPSTAT_API_TOKEN').

API docs

Check all the values for request and response fields here.

API credits consumption

1 per keyword in response.

Examples

Run this code
if (FALSE) {
sst_sa_related_keywords(
  keyword       = 'serpstat',
  se            = 'g_us',
  return_method = 'df'
)$data
}

Run the code above in your browser using DataLab