powered by
Returns a list of semantically related keywords for a given keyword.
sst_sa_related_keywords( keyword, se, with_intents = FALSE, filters = NULL, sort = NULL, page = 1, size = 100, return_method = "list", api_token = Sys.getenv("SERPSTAT_API_TOKEN") )
Returns related keywords for a keyword and their metrics.
(required) A keyword to search for.
(required) Search engine alias (db_name) returned by sst_sa_database_info.
sst_sa_database_info
(optional) TRUE if keyword intent should be retrieved. This parameter works for g_ua and g_us database only.
(optional) A list of filtering options. See API docs for more details.
(optional) A field to sort the response. See API docs for more details.
(optional) Response page number if there are many pages in response.
(optional) Response page size.
(optional) Accepted values are 'list' (default) to return data object as list or 'df' to return data object as data.frame.
(required) Serpstat API token from your profile. Default is Sys.getenv('SERPSTAT_API_TOKEN').
Check all the values for request and response fields here.
1 per keyword in response.
if (FALSE) { sst_sa_related_keywords( keyword = 'serpstat', se = 'g_us', return_method = 'df' )$data }
Run the code above in your browser using DataLab